@@ -12,6 +12,7 @@
 /*--------------------------------------------------------------------------*/
 #include "ScilabObjects.h"
 #include "JIMS.h"
+#define __USE_DEPRECATED_STACK_FUNCTIONS__
 #include "api_scilab.h"
 #include "stack-c.h"
 #include "Scierror.h"
@@ -19,10 +20,12 @@
 #include "OptionsHelper.h"
 #include "call_scilab.h"
 /*--------------------------------------------------------------------------*/
-#define _INVOKE_ "!_invoke_"
+#define _INVOKE_ "!!_invoke_"
 #define COPYINVOCATIONMACROTOSTACK "copyInvocationMacroToStack"
 /*--------------------------------------------------------------------------*/
 
+extern int C2F(varfunptr)(int *, int *,int *);
+
 static char isInit = 0;
 void initialization()
 {
@@ -30,8 +33,6 @@ void initialization()
     {
         int* mlistaddr = NULL;
         const char* fields[] = {"_JVoid"};
-        int id[nsiz];
-        int tops;
         SciErr err;
 
         createNamedJavaObject(_JOBJ, "jnull", 0);
@@ -50,16 +51,6 @@ void initialization()
             return;
         }
 
-        // to push the macro !_invoke_ on the stack
-        C2F(cvname)(id, _INVOKE_, &ZERO, strlen(_INVOKE_));
-        Fin = 0;
-        tops = Top;
-        Top = Top - Rhs + 2;
-        C2F(funs)(id);
-        Top = tops;
-        Fin = 0;
-        C2F(com).fun = 0;
-
         isInit = 1;
     }
 }
@@ -164,26 +155,33 @@ void copyInvocationMacroToStack(int pos)
 {
     static int init = 0;
     static int id[nsiz];
-    int dest = 0;
-
+    static int interf = 0;
+    static int funnumber = 0;
+    int tops = 0;
+    
     if (!init)
     {
-        C2F(str2name)(_INVOKE_, id, strlen(_INVOKE_));
-        init = 1;
+      int fins = 0;
+      int funs = 0;
+	init = 1;
+	C2F(str2name)(_INVOKE_, id, strlen(_INVOKE_));
+	fins = Fin;
+	funs = C2F(com).fun;
+	Fin = -1;
+	C2F(funs)(id);
+	funnumber = Fin;
+	interf = C2F(com).fun;
+	C2F(com).fun = funs;
+	Fin = fins;
     }
-
-    Fin = -1;
-    C2F(stackg)(id);
-    if (Fin == 0)
-    {
-        isInit = 0;
-        initialization();
-        Fin = -1;
-        C2F(stackg)(id);
-    }
-
-    dest = Top - Rhs + pos;
-    C2F(vcopyobj)(COPYINVOCATIONMACROTOSTACK, &Fin, &dest, strlen(COPYINVOCATIONMACROTOSTACK));
+    
+    tops = Top;
+    Top = Top - Rhs + pos - 1;
+    
+    // Create a function pointer variable
+    C2F(varfunptr)(id, &interf, &funnumber);
+    
+    Top = tops;
     setCopyOccured(1);
 }
 /*--------------------------------------------------------------------------*/
