@@ -64,7 +64,7 @@ void unwrapMat(JavaVM * jvm_, const bool methodOfConv, const int javaID, const i
     if (err.iErr)
     {
         curEnv->DeleteLocalRef(res);
-        throw ScilabObjects::NoMoreScilabMemoryException();
+        throw org_scilab_forge_jims::NoMoreScilabMemoryException();
     }
 
     T *resultsArray;
@@ -128,7 +128,7 @@ void unwrapRow(JavaVM * jvm_, const bool methodOfConv, const int javaID, const i
     if (err.iErr)
     {
         curEnv->DeleteLocalRef(res);
-        throw ScilabObjects::NoMoreScilabMemoryException();
+        throw org_scilab_forge_jims::NoMoreScilabMemoryException();
     }
 
     T *resultsArray = static_cast<T *>(curEnv->GetPrimitiveArrayCritical(res, &isCopy));
@@ -165,7 +165,7 @@ void unwrapSingle(JavaVM * jvm_, const bool methodOfConv, const int javaID, cons
 
     if (err.iErr)
     {
-        throw ScilabObjects::NoMoreScilabMemoryException();
+        throw org_scilab_forge_jims::NoMoreScilabMemoryException();
     }
 
     *addr = static_cast<U>(V::getSingleVar(curEnv, cls, id, javaID));
